aboutsummaryrefslogtreecommitdiff
path: root/src/policy
diff options
context:
space:
mode:
authorAlex Morcos <morcos@chaincode.com>2015-11-16 15:18:15 -0500
committerAlex Morcos <morcos@chaincode.com>2015-11-16 15:33:06 -0500
commitf22ac4a22c570921f1c2be121e6744a1564b2ce7 (patch)
tree8954f41b86154f914d0cd96e70732ab30e3449c4 /src/policy
parent4fe28236c0c16e20ddd539f38fc8d58db5eb83ed (diff)
downloadbitcoin-f22ac4a22c570921f1c2be121e6744a1564b2ce7.tar.xz
Increase success threshold for fee estimation to 95%
This provides more conservative estimates and reacts more quickly to a backlog. Unfortunately the unit test for fee estimation depends on the success threshold (and the decay) chosen; also modify the unit test for the new default success thresholds.
Diffstat (limited to 'src/policy')
-rw-r--r--src/policy/fees.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/policy/fees.h b/src/policy/fees.h
index 4c6e27fc11..07caa6e713 100644
--- a/src/policy/fees.h
+++ b/src/policy/fees.h
@@ -182,8 +182,8 @@ static const unsigned int MAX_BLOCK_CONFIRMS = 25;
/** Decay of .998 is a half-life of 346 blocks or about 2.4 days */
static const double DEFAULT_DECAY = .998;
-/** Require greater than 85% of X fee transactions to be confirmed within Y blocks for X to be big enough */
-static const double MIN_SUCCESS_PCT = .85;
+/** Require greater than 95% of X fee transactions to be confirmed within Y blocks for X to be big enough */
+static const double MIN_SUCCESS_PCT = .95;
static const double UNLIKELY_PCT = .5;
/** Require an avg of 1 tx in the combined fee bucket per block to have stat significance */